@@ -12,14 +12,19 @@ if TYPE_CHECKING:
 
 
 STORAGE_IMPLEMENTATIONS = {
-    "local": ".postgresql.storage.Storage",
     "remote": ".api.client.RemoteStorage",
     "memory": ".in_memory.InMemoryStorage",
-    "filter": ".filter.FilteringProxyStorage",
-    "buffer": ".buffer.BufferingProxyStorage",
-    "retry": ".retry.RetryingProxyStorage",
     "cassandra": ".cassandra.CassandraStorage",
-    "validate": ".validate.ValidatingProxyStorage",
+    "postgresql": ".postgresql.storage.Storage",
+    # deprecated
+    "local": ".postgresql.storage.Storage",
+    # proxy storages
+    "buffer": ".proxies.buffer.BufferingProxyStorage",
+    "counter": ".proxies.counter.CountingProxyStorage",
+    "filter": ".proxies.filter.FilteringProxyStorage",
+    "retry": ".proxies.retry.RetryingProxyStorage",
+    "tenacious": ".proxies.tenacious.TenaciousProxyStorage",
+    "validate": ".proxies.validate.ValidatingProxyStorage",
 }
 
 
@@ -55,6 +60,12 @@ def get_storage(cls: str, **kwargs) -> "StorageInterface":
     if cls == "pipeline":
         return get_storage_pipeline(**kwargs)
 
+    if cls == "local":
+        warnings.warn(
+            'The "local" storage class is deprecated, use "postgresql" instead.',
+            DeprecationWarning,
+        )
+
     class_path = STORAGE_IMPLEMENTATIONS.get(cls)
     if class_path is None:
         raise ValueError(
