@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020  The Software Heritage developers
+# Copyright (C) 2017-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -80,9 +80,9 @@ COLUMNS = {
         "reason",
     ],
     "directory": ["id", "dir_entries", "file_entries", "rev_entries"],
-    "extid": ["extid_type", "extid", "target_type", "target"],
-    "metadata_authority": ["type", "url", "metadata",],
-    "metadata_fetcher": ["name", "version", "metadata",],
+    "extid": ["extid_type", "extid", "extid_version", "target_type", "target"],
+    "metadata_authority": ["type", "url"],
+    "metadata_fetcher": ["name", "version"],
     "origin": ["url"],
     "origin_visit": ["visit", "type", ("origin.url", "origin"), "date",],
     "origin_visit_status": [
@@ -174,6 +174,11 @@ JOINS = {
     ],
 }
 
+EXTRA_WHERE = {
+    # hack to force the right index usage on table extid
+    "extid": "target_type in ('revision', 'release', 'content', 'directory')"
+}
+
 
 def directory_converter(db: BaseDb, directory_d: Dict[str, Any]) -> Directory:
     """Convert directory from the flat representation to swh model
@@ -461,6 +466,7 @@ def compute_query(obj_type, start, end):
     columns = COLUMNS.get(obj_type)
     join_specs = JOINS.get(obj_type, [])
     join_clause = "\n".join("left join %s" % clause for clause in join_specs)
+    additional_where = EXTRA_WHERE.get(obj_type)
 
     where = []
     where_args = []
@@ -471,6 +477,9 @@ def compute_query(obj_type, start, end):
         where.append("%(keys)s < %%s")
         where_args.append(end)
 
+    if additional_where:
+        where.append(additional_where)
+
     where_clause = ""
     if where:
         where_clause = ("where " + " and ".join(where)) % {
@@ -572,7 +581,10 @@ class JournalBackfiller:
                 " provided: %s" % (",".join(missing_keys),)
             )
 
-        if "cls" not in config["storage"] or config["storage"]["cls"] != "local":
+        if "cls" not in config["storage"] or config["storage"]["cls"] not in (
+            "local",
+            "postgresql",
+        ):
             raise ValueError(
                 "swh storage backfiller must be configured to use a local"
                 " (PostgreSQL) storage"
