@@ -3,39 +3,56 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+import os
+
+_use_scylla = bool(os.environ.get("SWH_USE_SCYLLADB", ""))
+
+UDF_LANGUAGE = "lua" if _use_scylla else "java"
+
+if UDF_LANGUAGE == "java":
+    # For Cassandra
+    CREATE_TABLES_QUERIES = [
+        """
+        CREATE OR REPLACE FUNCTION ascii_bins_count_sfunc (
+            state tuple<int, map<ascii, int>>, -- (nb_none, map<target_type, nb>)
+            bin_name ascii
+        )
+        CALLED ON NULL INPUT
+        RETURNS tuple<int, map<ascii, int>>
+        LANGUAGE java AS
+        $$
+            if (bin_name == null) {
+                state.setInt(0, state.getInt(0) + 1);
+            }
+            else {
+                Map<String, Integer> counters = state.getMap(
+                    1, String.class, Integer.class);
+                Integer nb = counters.get(bin_name);
+                if (nb == null) {
+                    nb = 0;
+                }
+                counters.put(bin_name, nb + 1);
+                state.setMap(1, counters, String.class, Integer.class);
+            }
+            return state;
+        $$;""",
+        """
+        CREATE OR REPLACE AGGREGATE ascii_bins_count ( ascii )
+        SFUNC ascii_bins_count_sfunc
+        STYPE tuple<int, map<ascii, int>>
+        INITCOND (0, {})
+        ;""",
+    ]
+elif UDF_LANGUAGE == "lua":
+    # For ScyllaDB
+    # TODO: this is not implementable yet, because ScyllaDB does not support
+    # user-defined aggregates. https://github.com/scylladb/scylla/issues/7201
+    CREATE_TABLES_QUERIES = []
+else:
+    assert False, f"{UDF_LANGUAGE} must be 'lua' or 'java'"
 
 CREATE_TABLES_QUERIES = [
-    """
-CREATE OR REPLACE FUNCTION ascii_bins_count_sfunc (
-    state tuple<int, map<ascii, int>>, -- (nb_none, map<target_type, nb>)
-    bin_name ascii
-)
-CALLED ON NULL INPUT
-RETURNS tuple<int, map<ascii, int>>
-LANGUAGE java AS
-$$
-    if (bin_name == null) {
-        state.setInt(0, state.getInt(0) + 1);
-    }
-    else {
-        Map<String, Integer> counters = state.getMap(
-            1, String.class, Integer.class);
-        Integer nb = counters.get(bin_name);
-        if (nb == null) {
-            nb = 0;
-        }
-        counters.put(bin_name, nb + 1);
-        state.setMap(1, counters, String.class, Integer.class);
-    }
-    return state;
-$$
-;""",
-    """
-CREATE OR REPLACE AGGREGATE ascii_bins_count ( ascii )
-SFUNC ascii_bins_count_sfunc
-STYPE tuple<int, map<ascii, int>>
-INITCOND (0, {})
-;""",
+    *CREATE_TABLES_QUERIES,
     """
 CREATE TYPE IF NOT EXISTS microtimestamp (
     seconds             bigint,
@@ -63,7 +80,7 @@ CREATE TABLE IF NOT EXISTS content (
     ctime         timestamp,
         -- creation time, i.e. time of (first) injection into the storage
     status        ascii,
-    PRIMARY KEY ((sha1, sha1_git, sha256, blake2s256))
+    PRIMARY KEY ((sha256), sha1, sha1_git, blake2s256)
 );""",
     """
 CREATE TABLE IF NOT EXISTS skipped_content (
@@ -162,7 +179,9 @@ CREATE TABLE IF NOT EXISTS origin_visit_status (
     metadata        text,
     snapshot        blob,
     PRIMARY KEY ((origin), visit, date)
-);""",
+)
+WITH CLUSTERING ORDER BY (visit DESC, date DESC)
+;""",  # 'WITH CLUSTERING ORDER BY' is optional with Cassandra 4, but ScyllaDB needs it
     """
 CREATE TABLE IF NOT EXISTS origin (
     sha1            blob PRIMARY KEY,
@@ -176,14 +195,12 @@ CREATE TABLE IF NOT EXISTS origin (
 CREATE TABLE IF NOT EXISTS metadata_authority (
     url             text,
     type            ascii,
-    metadata        text,
     PRIMARY KEY ((url), type)
 );""",
     """
 CREATE TABLE IF NOT EXISTS metadata_fetcher (
     name            ascii,
     version         ascii,
-    metadata        text,
     PRIMARY KEY ((name), version)
 );""",
     """
@@ -242,19 +259,21 @@ CREATE TABLE IF NOT EXISTS raw_extrinsic_metadata (
     --    <=> (target1, ..., date1, id1) == (target2, ..., date2, id2)
 );""",
     """
-CREATE TABLE IF NOT EXISTS object_count (
-    partition_key   smallint,  -- Constant, must always be 0
-    object_type     ascii,
-    count           counter,
-    PRIMARY KEY ((partition_key), object_type)
+CREATE TABLE IF NOT EXISTS raw_extrinsic_metadata_by_id (
+    id              blob,
+    target          text,
+    authority_type  text,
+    authority_url   text,
+    PRIMARY KEY ((id))
 );""",
     """
 CREATE TABLE IF NOT EXISTS extid (
     extid_type      ascii,
     extid           blob,
+    extid_version   smallint,
     target_type     ascii,
     target          blob,
-    PRIMARY KEY ((extid_type, extid), target_type, target)
+    PRIMARY KEY ((extid_type, extid), extid_version, target_type, target)
 );""",
     """
 CREATE TABLE IF NOT EXISTS extid_by_target (
@@ -293,7 +312,6 @@ TABLES = [
     "origin_visit",
     "origin",
     "raw_extrinsic_metadata",
-    "object_count",
     "origin_visit_status",
     "metadata_authority",
     "metadata_fetcher",
