@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2020  The Software Heritage developers
+# Copyright (C) 2015-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -15,6 +15,7 @@ from swh.model.identifiers import ExtendedSWHID, ObjectType
 from swh.model.model import (
     Content,
     Directory,
+    DirectoryEntry,
     ExtID,
     MetadataAuthority,
     MetadataAuthorityType,
@@ -74,7 +75,7 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("content/add")
-    def content_add(self, content: List[Content]) -> Dict:
+    def content_add(self, content: List[Content]) -> Dict[str, int]:
         """Add content blobs to the storage
 
         Args:
@@ -134,7 +135,7 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("content/add_metadata")
-    def content_add_metadata(self, content: List[Content]) -> Dict:
+    def content_add_metadata(self, content: List[Content]) -> Dict[str, int]:
         """Add content metadata to the storage (like `content_add`, but
         without inserting to the objstorage).
 
@@ -202,11 +203,15 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("content/metadata")
-    def content_get(self, contents: List[Sha1]) -> List[Optional[Content]]:
+    def content_get(
+        self, contents: List[bytes], algo: str = "sha1"
+    ) -> List[Optional[Content]]:
         """Retrieve content metadata in bulk
 
         Args:
             content: List of content identifiers
+            algo: one of the checksum algorithm in
+              :data:`swh.model.hashutil.DEFAULT_ALGORITHMS`
 
         Returns:
             List of contents model objects when they exist, None otherwise.
@@ -297,7 +302,7 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("content/skipped/add")
-    def skipped_content_add(self, content: List[SkippedContent]) -> Dict:
+    def skipped_content_add(self, content: List[SkippedContent]) -> Dict[str, int]:
         """Add contents to the skipped_content list, which contains
         (partial) information about content missing from the archive.
 
@@ -350,7 +355,7 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("directory/add")
-    def directory_add(self, directories: List[Directory]) -> Dict:
+    def directory_add(self, directories: List[Directory]) -> Dict[str, int]:
         """Add directories to the storage
 
         Args:
@@ -426,6 +431,31 @@ class StorageInterface(Protocol):
         """
         ...
 
+    @remote_api_endpoint("directory/get_entries")
+    def directory_get_entries(
+        self,
+        directory_id: Sha1Git,
+        page_token: Optional[bytes] = None,
+        limit: int = 1000,
+    ) -> Optional[PagedResult[DirectoryEntry]]:
+        """Get the content, possibly partial, of a directory with the given id
+
+        The entries of the directory are not guaranteed to be returned in any
+        particular order.
+
+        The number of results is not guaranteed to be lower than the ``limit``.
+
+        Args:
+            directory_id: dentifier of the directory
+            page_token: opaque string used to get the next results of a search
+            limit: Number of entries to return
+
+        Returns:
+            None if the directory does not exist; a page of DirectoryEntry
+              objects otherwise.
+        """
+        ...
+
     @remote_api_endpoint("directory/get_random")
     def directory_get_random(self) -> Sha1Git:
         """Finds a random directory id.
@@ -436,7 +466,7 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("revision/add")
-    def revision_add(self, revisions: List[Revision]) -> Dict:
+    def revision_add(self, revisions: List[Revision]) -> Dict[str, int]:
         """Add revisions to the storage
 
         Args:
@@ -502,12 +532,15 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("extid/from_extid")
-    def extid_get_from_extid(self, id_type: str, ids: List[bytes]) -> List[ExtID]:
+    def extid_get_from_extid(
+        self, id_type: str, ids: List[bytes], version: Optional[int] = None
+    ) -> List[ExtID]:
         """Get ExtID objects from external IDs
 
         Args:
             id_type: type of the given external identifiers (e.g. 'mercurial')
             ids: list of external IDs
+            version: (Optional) version to use as filter
 
         Returns:
             list of ExtID objects
@@ -517,13 +550,24 @@ class StorageInterface(Protocol):
 
     @remote_api_endpoint("extid/from_target")
     def extid_get_from_target(
-        self, target_type: ObjectType, ids: List[Sha1Git]
+        self,
+        target_type: ObjectType,
+        ids: List[Sha1Git],
+        extid_type: Optional[str] = None,
+        extid_version: Optional[int] = None,
     ) -> List[ExtID]:
         """Get ExtID objects from target IDs and target_type
 
         Args:
             target_type: type the SWH object
             ids: list of target IDs
+            extid_type: (Optional) extid_type to use as filter. This cannot be empty if
+              extid_version is provided.
+            extid_version: (Optional) version to use as filter. This cannot be empty if
+              extid_type is provided.
+
+        Raises:
+            ValueError if extid_version is provided without extid_type and vice versa.
 
         Returns:
             list of ExtID objects
@@ -587,7 +631,7 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("release/add")
-    def release_add(self, releases: List[Release]) -> Dict:
+    def release_add(self, releases: List[Release]) -> Dict[str, int]:
         """Add releases to the storage
 
         Args:
@@ -652,7 +696,7 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("snapshot/add")
-    def snapshot_add(self, snapshots: List[Snapshot]) -> Dict:
+    def snapshot_add(self, snapshots: List[Snapshot]) -> Dict[str, int]:
         """Add snapshots to the storage.
 
         Args:
@@ -810,7 +854,9 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("origin/visit_status/add")
-    def origin_visit_status_add(self, visit_statuses: List[OriginVisitStatus],) -> None:
+    def origin_visit_status_add(
+        self, visit_statuses: List[OriginVisitStatus],
+    ) -> Dict[str, int]:
         """Add origin visit statuses.
 
         If there is already a status for the same origin and visit id at the same
@@ -1132,7 +1178,9 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("raw_extrinsic_metadata/add")
-    def raw_extrinsic_metadata_add(self, metadata: List[RawExtrinsicMetadata],) -> None:
+    def raw_extrinsic_metadata_add(
+        self, metadata: List[RawExtrinsicMetadata],
+    ) -> Dict[str, int]:
         """Add extrinsic metadata on objects (contents, directories, ...).
 
         The authority and fetcher must be known to the storage before
@@ -1157,7 +1205,7 @@ class StorageInterface(Protocol):
         page_token: Optional[bytes] = None,
         limit: int = 1000,
     ) -> PagedResult[RawExtrinsicMetadata]:
-        """Retrieve list of all raw_extrinsic_metadata entries for the id
+        """Retrieve list of all raw_extrinsic_metadata entries targeting the id
 
         Args:
             target: the SWHID of the objects to find metadata on
@@ -1172,8 +1220,29 @@ class StorageInterface(Protocol):
         """
         ...
 
+    @remote_api_endpoint("raw_extrinsic_metadata/get_by_ids")
+    def raw_extrinsic_metadata_get_by_ids(
+        self, ids: List[Sha1Git]
+    ) -> List[RawExtrinsicMetadata]:
+        """Retrieve list of raw_extrinsic_metadata entries of the given id
+        (unlike raw_extrinsic_metadata_get, which returns metadata entries
+        **targeting** the id)
+
+        Args:
+            ids: list of hashes of RawExtrinsicMetadata objects
+
+        """
+        ...
+
+    @remote_api_endpoint("raw_extrinsic_metadata/get_authorities")
+    def raw_extrinsic_metadata_get_authorities(
+        self, target: ExtendedSWHID
+    ) -> List[MetadataAuthority]:
+        """Returns all authorities that provided metadata on the given object."""
+        ...
+
     @remote_api_endpoint("metadata_fetcher/add")
-    def metadata_fetcher_add(self, fetchers: List[MetadataFetcher],) -> None:
+    def metadata_fetcher_add(self, fetchers: List[MetadataFetcher],) -> Dict[str, int]:
         """Add new metadata fetchers to the storage.
 
         Their `name` and `version` together are unique identifiers of this
@@ -1205,7 +1274,9 @@ class StorageInterface(Protocol):
         ...
 
     @remote_api_endpoint("metadata_authority/add")
-    def metadata_authority_add(self, authorities: List[MetadataAuthority]) -> None:
+    def metadata_authority_add(
+        self, authorities: List[MetadataAuthority]
+    ) -> Dict[str, int]:
         """Add new metadata authorities to the storage.
 
         Their `type` and `url` together are unique identifiers of this
