@@ -414,6 +414,34 @@ begin
 end
 $$;
 
+-- Returns the entries in a directory, without joining with their target tables
+create or replace function swh_directory_get_entries(dir_id sha1_git)
+    returns table (
+        dir_id directory_entry_type, target sha1_git, name unix_path, perms file_perms
+    )
+    language sql
+    stable
+as $$
+    with dir as (
+	select id as dir_id, dir_entries, file_entries, rev_entries
+	from directory
+	where id = dir_id),
+    ls_d as (select dir_id, unnest(dir_entries) as entry_id from dir),
+    ls_f as (select dir_id, unnest(file_entries) as entry_id from dir),
+    ls_r as (select dir_id, unnest(rev_entries) as entry_id from dir)
+    (select 'dir'::directory_entry_type, e.target, e.name, e.perms
+     from ls_d
+     left join directory_entry_dir e on ls_d.entry_id = e.id)
+    union
+	(select 'file'::directory_entry_type, e.target, e.name, e.perms
+     from ls_f
+     left join directory_entry_file e on ls_f.entry_id = e.id)
+    union
+    (select 'rev'::directory_entry_type, e.target, e.name, e.perms
+     from ls_r
+     left join directory_entry_rev e on ls_r.entry_id = e.id)
+$$;
+
 -- List all revision IDs starting from a given revision, going back in time
 --
 -- TODO ordering: should be breadth-first right now (what do we want?)
@@ -557,8 +585,8 @@ create or replace function swh_extid_add()
     language plpgsql
 as $$
 begin
-    insert into extid (extid_type, extid, target_type, target)
-        select distinct t.extid_type, t.extid, t.target_type, t.target
+    insert into extid (extid_type, extid, extid_version, target_type, target)
+        select distinct t.extid_type, t.extid, t.extid_version, t.target_type, t.target
         from tmp_extid t
 		on conflict do nothing;
     return;
