@@ -1,4 +1,4 @@
-# Copyright (C) 2019 The Software Heritage developers
+# Copyright (C) 2019-2021 The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -29,7 +29,7 @@ TEST_CONFIG = {
         "prefix": "swh.tmp_journal.new",
         "client_id": "swh.journal.client.test",
     },
-    "storage": {"cls": "local", "db": "service=swh-dev"},
+    "storage": {"cls": "postgresql", "db": "service=swh-dev"},
 }
 
 
