@@ -7,21 +7,18 @@ import copy
 import logging
 import re
 import tempfile
-import yaml
-
 from unittest.mock import patch
 
-import pytest
-
 from click.testing import CliRunner
 from confluent_kafka import Producer
+import pytest
+import yaml
 
-from swh.model.model import Snapshot, SnapshotBranch, TargetType
 from swh.journal.serializers import key_to_kafka, value_to_kafka
+from swh.model.model import Snapshot, SnapshotBranch, TargetType
 from swh.storage import get_storage
 from swh.storage.cli import storage as cli
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -34,7 +31,7 @@ CLI_CONFIG = {
 def swh_storage():
     """An swh-storage object that gets injected into the CLI functions."""
     storage = get_storage(**CLI_CONFIG["storage"])
-    with patch("swh.storage.cli.get_storage") as get_storage_mock:
+    with patch("swh.storage.get_storage") as get_storage_mock:
         get_storage_mock.return_value = storage
         yield storage
 
